express_matrix: Express matrix.

View source: R/core.R

express_matrixR Documentation

Express matrix.

Description

Takes a named matrix and writes the R code to populate it; useful for generating input expressions from calibration results.

Usage

express_matrix(mtx)

Arguments

mtx

a matrix

Value

Invisibly returns the generated R code as a character string, also outputs via message().


epicR documentation built on March 8, 2026, 5:06 p.m.