| get_input | R Documentation |
Returns a list of default model input values
get_input(
age0 = 40,
time_horizon = 20,
discount_cost = 0,
discount_qaly = 0.03,
closed_cohort = 0,
jurisdiction = "canada"
)
age0 |
Starting age in the model |
time_horizon |
Model time horizon |
discount_cost |
Discounting for cost outcomes |
discount_qaly |
Discounting for QALY outcomes |
closed_cohort |
Whether the model should run as closed_cohort, open-population by default. |
jurisdiction |
Jurisdiction for model parameters ("canada" or "us") |
A list with four components:
A nested list of model input parameter values
A nested list of help text descriptions for each parameter
A nested list of reference information for each parameter
The raw configuration object loaded from the JSON file
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.