get_output: Main outputs of the current run.

View source: R/RcppExports.R

get_outputR Documentation

Main outputs of the current run.

Description

Main outputs of the current run.

Usage

get_output()

Value

number of agents, cumulative time, number of deaths, number of COPD cases, as well as exacerbation statistics and QALYs.


epicR documentation built on March 8, 2026, 5:06 p.m.