| validate_diagnosis | R Documentation |
This function returns a table showing the proportion of COPD patients diagnosed over the model's runtime. It also provides a second table that breaks down the proportion of diagnosed patients by COPD severity. Additionally, the function generates a plot to visualize the distribution of diagnoses over time.
validate_diagnosis(n_sim = 10000, jurisdiction = "canada")
n_sim |
number of agents |
jurisdiction |
character string specifying the jurisdiction ("canada" or "us"). Default is "canada" |
validation test results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.