| validate_payoffs | R Documentation |
Returns results of validation tests for payoffs, costs and QALYs
validate_payoffs(
nPatient = 1e+06,
disableDiscounting = TRUE,
disableExacMortality = TRUE,
jurisdiction = "canada"
)
nPatient |
number of simulated patients. Default is 1e6. |
disableDiscounting |
if TRUE, discounting will be disabled for cost and QALY calculations. Default: TRUE |
disableExacMortality |
if TRUE, mortality due to exacerbations will be disabled for cost and QALY calculations. Default: TRUE |
jurisdiction |
character string specifying the jurisdiction for validation ("canada" or "us"). Default is "canada". Currently only "canada" is implemented. |
validation test results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.