| validate_treatment | R Documentation |
This function runs validation tests to examine how treatment initiated at diagnosis influences exacerbation rates in COPD patients. It compares exacerbation rates between diagnosed and undiagnosed patients and assesses the impact of treatment.
validate_treatment(n_sim = 10000, jurisdiction = "canada")
n_sim |
number of agents |
jurisdiction |
character string specifying the jurisdiction ("canada" or "us"). Default is "canada" |
validation test results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.