export_figures: Runs the model and exports an excel file with all output data
Description
Runs the model and exports an excel file with all output data
Usage
export_figures(nPatients = 10000)
Value
an excel file with all output
Arguments
- nPatients
number of agents