| express_matrix | R Documentation |
Takes a named matrix and writes the R code to populate it; useful for generating input expressions from calibration results.
express_matrix(mtx)
mtx |
a matrix |
Invisibly returns the generated R code as a character string, also outputs via message().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.