Express matrix.
express_matrix.RdTakes a named matrix and writes the R code to populate it; useful for generating input expressions from calibration results.
express_matrix.RdTakes a named matrix and writes the R code to populate it; useful for generating input expressions from calibration results.