Returns a list of default model input values
get_input(
age0 = 40,
time_horizon = 20,
discount_cost = 0,
discount_qaly = 0.03,
closed_cohort = 0,
jurisdiction = "canada"
)A list with four components:
A nested list of model input parameter values
A nested list of help text descriptions for each parameter
A nested list of reference information for each parameter
The raw configuration object loaded from the JSON file
Starting age in the model
Model time horizon
Discounting for cost outcomes
Discounting for QALY outcomes
Whether the model should run as closed_cohort, open-population by default.
Jurisdiction for model parameters ("canada" or "us")