| get_list_elements | R Documentation |
Recursively extracts element names from a nested list structure.
get_list_elements(ls, running_name = "")
ls |
A list to extract element names from |
running_name |
Internal parameter for recursion (default: "") |
A character vector of element names, with nested elements separated by "$" (e.g., "parent$child$grandchild").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.