Learn R Programming

epicR (version 1.0.2)

get_output: Main outputs of the current run.

Description

Main outputs of the current run.

Usage

get_output()

Arguments

Value

number of agents, cumulative time, number of deaths, number of COPD cases, as well as exacerbation statistics and QALYs.