get_sample_output: Returns a sample output for a given year and gender.
Description
Returns a sample output for a given year and gender.
Usage
get_sample_output(year, sex)
Value
that specific output
Arguments
- year
a number
- sex
a number, 0 for male and 1 for female