Returns results of validation tests for payoffs, costs and QALYs
validate_payoffs(
nPatient = 1e+06,
disableDiscounting = TRUE,
disableExacMortality = TRUE,
jurisdiction = "canada"
)validation test results
number of simulated patients. Default is 1e6.
if TRUE, discounting will be disabled for cost and QALY calculations. Default: TRUE
if TRUE, mortality due to exacerbations will be disabled for cost and QALY calculations. Default: TRUE
character string specifying the jurisdiction for validation ("canada" or "us"). Default is "canada". Currently only "canada" is implemented.