Returns simulated vs. predicted population table and a plot
validate_population(
remove_COPD = 0,
incidence_k = 1,
savePlots = 0,
jurisdiction = "canada"
)For Canada: returns a table showing predicted (StatsCan) and simulated population values. For US: returns a data frame with population comparisons by age group and year.
0 or 1, indicating whether COPD-caused mortality should be removed
a number (default=1) by which the incidence rate of population will be multiplied.
0 or 1, exports 300 DPI population growth and pyramid plots comparing simulated vs. predicted population
character string specifying the jurisdiction for validation ("canada" or "us"). Default is "canada".